package com.lantone.qc.kernel.catalogue.threelevelward;

import com.lantone.qc.kernel.catalogue.QCCatalogue;
import com.lantone.qc.pub.Content;
import com.lantone.qc.pub.model.InputInfo;
import com.lantone.qc.pub.model.OutputInfo;
import com.lantone.qc.pub.model.doc.DoctorAdviceDoc;
import com.lantone.qc.pub.model.doc.PacsDoc;
import com.lantone.qc.pub.util.ListUtil;
import com.lantone.qc.pub.util.StringUtil;
import org.springframework.stereotype.Component;

import java.util.List;
import java.util.Map;

/**
 * @ClassName : THE03112
 * @Description :  医嘱存在MR,报告单未记录
 * @Author : zh
 * @Date: 2021-04-06 17:06
 */
@Component
public class THE03112 extends QCCatalogue {
    @Override
    public void start(InputInfo inputInfo, OutputInfo outputInfo) {
        status.set("0");
        int ctNum = 0;
        int bcNum = 0;
        List<DoctorAdviceDoc> doctorAdviceDocsList = inputInfo.getDoctorAdviceDocs();
        if (ListUtil.isNotEmpty(doctorAdviceDocsList)) {
            for (DoctorAdviceDoc doctorAdviceDoc : doctorAdviceDocsList) {
                Map<String, String> doctorAdviceDocStructureMap = doctorAdviceDoc.getStructureMap();
                String daStatus = doctorAdviceDocStructureMap.get(Content.doctorAdviceState);
                if(StringUtil.isEmpty(daStatus) || (!daStatus.equals(Content.cancellationOrder) && StringUtil.isNotEmpty(daStatus))){
                    //ct取临时医嘱
                    String doctorAsks = doctorAdviceDocStructureMap.get(Content.doctorAdviceType);
                    if (StringUtil.isNotEmpty(doctorAsks)) {
                        if (Content.statOrder.equals(doctorAsks)) {
                            //取医嘱项目名称
                            String daItemName = doctorAdviceDocStructureMap.get(Content.medicalOrderName);
                            if (daItemName.contains("磁共振") || daItemName.contains("MR")) {
                                if (!daItemName.contains("IMRT") && !daItemName.contains("mrs评分")) {
                                    ctNum++;
                                    continue;
                                }
                            }
                        }
                    }
                }
            }
            List<PacsDoc> pacsDocs = inputInfo.getPacsDocs();
            if(ListUtil.isNotEmpty(pacsDocs)){
                if(pacsDocs.size()>0) {
                    for (PacsDoc pacsDoc : pacsDocs) {
                        String pacsDocStr = pacsDoc.getStructureMap().get(Content.reportName);
                        if (StringUtil.isNotEmpty(pacsDocStr) ) {
                            if( pacsDocStr.contains("MR")||pacsDocStr.contains("磁共振")) {
                                bcNum++;
                                continue;
                            }
                        }
                    }
                }
            }
            if ((ctNum != bcNum)&&(ctNum>bcNum)) {
                status.set("-1");
            }
        }
    }
}
