package com.lantone.qc.kernel.catalogue.threelevelward;

import com.lantone.qc.kernel.catalogue.QCCatalogue;
import com.lantone.qc.pub.Content;
import com.lantone.qc.pub.model.InputInfo;
import com.lantone.qc.pub.model.OutputInfo;
import com.lantone.qc.pub.model.doc.DoctorAdviceDoc;
import com.lantone.qc.pub.model.doc.ThreeLevelWardDoc;
import com.lantone.qc.pub.util.ListUtil;
import com.lantone.qc.pub.util.MapUtil;
import com.lantone.qc.pub.util.StringUtil;
import org.springframework.stereotype.Component;

import java.util.List;
import java.util.Map;

/**
 * @ClassName : THR03115
 * @Description :  接受CT情况下病程记录缺少CT检查记录
 * @Author : zh
 * @Date: 2021-04-06 17:06
 */
@Component
public class THR03115 extends QCCatalogue {
    @Override
    public void start(InputInfo inputInfo, OutputInfo outputInfo) {
        status.set("0");
        int ctNum=0;
        int bcNum=0;
        List<DoctorAdviceDoc> doctorAdviceDocsList = inputInfo.getDoctorAdviceDocs();
        if(ListUtil.isNotEmpty(doctorAdviceDocsList)) {
            for (DoctorAdviceDoc doctorAdviceDoc : doctorAdviceDocsList) {
                Map<String, String> doctorAdviceDocStructureMap = doctorAdviceDoc.getStructureMap();
                String daStatus = doctorAdviceDocStructureMap.get(Content.doctorAdviceState);
                if (StringUtil.isEmpty(daStatus) || (!daStatus.equals(Content.cancellationOrder) && StringUtil.isNotEmpty(daStatus))) {
                    //ct取临时医嘱
                    String doctorAsks = doctorAdviceDocStructureMap.get(Content.doctorAdviceType);
                    if (Content.statOrder.equals(doctorAsks)) {
                        //取医嘱项目名称
                        String daItemName = doctorAdviceDocStructureMap.get(Content.medicalOrderName);
                        if (daItemName.contains("CT") || daItemName.contains("X线")) {
                            if ((!daItemName.contains("ATCH") && !daItemName.contains("TCT") && !daItemName.contains("HCT") && !daItemName.contains("OCT") && !daItemName.contains("NCT") && !daItemName.contains("LCT") && !daItemName.contains("ACT")) || (daItemName.contains("停"))) {
                                //都不包含为CT
                                ctNum++;
                                continue;
                            }
                        }
                    }
                }
            }
            List<ThreeLevelWardDoc> threeLevelWardDocs = inputInfo.getThreeLevelWardDocs();
            if (ListUtil.isNotEmpty(threeLevelWardDocs)) {
                List<ThreeLevelWardDoc> allDoctorWradDocs = threeLevelWardDocs.get(0).getAllDoctorWradDocs();
                if (ListUtil.isNotEmpty(allDoctorWradDocs)) {
                    for (ThreeLevelWardDoc allDoctorWradDoc : allDoctorWradDocs) {
                        Map<String, String> structureMap = allDoctorWradDoc.getStructureMap();
                        String records = structureMap.get(Content.illnessRecords);
                        if (StringUtil.isNotEmpty(records)) {
                            if (records.contains("CT") || records.contains("X线")) {
                                bcNum++;
                            }
                        }
                    }
                }
            }
            if((ctNum != bcNum)&&(ctNum>bcNum)){
                status.set("-1");
            }
        }
    }

}
